# Paprika Exporter

Export Paprika data using the API to yaml

# Introduction

This tool statically generates a list of Paprika recipes in YAML format, with a related folder of images. 

# Installation

pip3 install papexp

# Example python code

import papexp
from papexp import export
export.exportrecipes()

# Examples on the web

You can see that on [my website][1]

[My website repository][2] incorporates this code to routinely pull new recipes. 

This code is almost entirely the work of [Shane Starcher][3]. I’m deeply grateful to him for building this.

My goal with this package is to make implementation of his code on your website dead simple.

[1]:	https://chrisfnicholson.com/recipes.html
[2]:	http://www.github.com/datapolitical/chrisfnicholson.github.io
[3]:	https://github.com/sstarcher/paprika-exporter

